InstanceConfig

Struct InstanceConfig 

pub struct InstanceConfig {
    pub name: String,
    pub region: String,
    pub availability_zone_group: Option<String>,
    pub instance_type: String,
    pub storage_size: i32,
    pub storage_class: String,
    pub storage_iops: Option<i32>,
    pub storage_throughput: Option<i32>,
    pub binary: String,
    pub config: String,
    pub profiling: bool,
}
Instance configuration

Fields

name: String

Name of the instance

region: String

AWS region where the instance is deployed

availability_zone_group: Option<String>

Optional group whose instances in the same region must launch in the same availability zone.

The same group name may be reused in different regions, but each region is resolved independently and the group will not span regions.

instance_type: String

Instance type (e.g., t4g.small for ARM64, t3.small for x86_64)

storage_size: i32

Storage size in GB

storage_class: String

Storage class (e.g., “gp2”)

storage_iops: Option<i32>

Provisioned IOPS for volumes that support it

storage_throughput: Option<i32>

Provisioned throughput in MiB/s for volumes that support it

binary: String

Path to the binary to deploy

config: String

Path to the binary configuration file

profiling: bool

Whether to enable profiling